@@ -1,17 +1,21 @@
+
 #[cfg(target_os = "windows")]
 mod keyboard;
 #[doc(inline)]
 pub use keyboard::*;
 
-mod utils;
-
 mod memory;
 #[doc(inline)]
 pub use memory::*;
 
+mod memory_ex;
 #[doc(inline)]
-pub use self::utils::*;
+pub use memory_ex::*;
+
+mod utils;
+#[doc(inline)]
+pub use utils::*;
 
 pub trait GameObject {
     unsafe fn from_raw(address: *const usize) -> Option<*mut Self>;
-}
\ No newline at end of file
+}
